@@ -1,33 +1,32 @@
-# coding=utf-8
 """Support for mixed digit/string type Issue field
 
 Class for handling the odd permutations of an 'issue number' that the
 comics industry throws at us.
   e.g.: "12", "12.1", "0", "-1", "5AU", "100-2"
 """
-
 # Copyright 2012-2014 Anthony Beville
-
+#
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
 # You may obtain a copy of the License at
-
+#
 #     http://www.apache.org/licenses/LICENSE-2.0
-
+#
 # Unless required by applicable law or agreed to in writing, software
 # distributed under the License is distributed on an "AS IS" BASIS,
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
+from __future__ import annotations
 
-#import utils
-#import math
-#import re
+import logging
+import unicodedata
+
+logger = logging.getLogger(__name__)
 
 
 class IssueString:
-
-    def __init__(self, text):
+    def __init__(self, text: str | None) -> None:
 
         # break up the issue number string into 2 parts: the numeric and suffix string.
         # (assumes that the numeric portion is always first)
@@ -43,18 +42,15 @@ class IssueString:
         if len(text) == 0:
             return
 
-        text = str(text)
-
         # skip the minus sign if it's first
-        if text[0] == '-':
+        if text[0] == "-":
             start = 1
         else:
             start = 0
 
         # if it's still not numeric at start skip it
         if text[start].isdigit() or text[start] == ".":
-            # walk through the string, look for split point (the first
-            # non-numeric)
+            # walk through the string, look for split point (the first non-numeric)
             decimal_count = 0
             for idx in range(start, len(text)):
                 if text[idx] not in "0123456789.":
@@ -72,13 +68,12 @@ class IssueString:
             if text[idx - 1] == "." and len(text) != idx:
                 idx = idx - 1
 
-            # if there is no numeric after the minus, make the minus part of
-            # the suffix
+            # if there is no numeric after the minus, make the minus part of the suffix
             if idx == 1 and start == 1:
                 idx = 0
 
             part1 = text[0:idx]
-            part2 = text[idx:len(text)]
+            part2 = text[idx : len(text)]
 
             if part1 != "":
                 self.num = float(part1)
@@ -86,9 +81,7 @@ class IssueString:
         else:
             self.suffix = text
 
-        # print "num: {0} suf: {1}".format(self.num, self.suffix)
-
-    def asString(self, pad=0):
+    def as_string(self, pad: int = 0) -> str:
         # return the float, left side zero-padded, with suffix attached
         if self.num is None:
             return self.suffix
@@ -106,9 +99,9 @@ class IssueString:
 
         # create padding
         padding = ""
-        l = len(str(num_int))
-        if l < pad:
-            padding = "0" * (pad - l)
+        length = len(str(num_int))
+        if length < pad:
+            padding = "0" * (pad - length)
 
         num_s = padding + num_s
         if negative:
@@ -116,17 +109,8 @@ class IssueString:
 
         return num_s
 
-    def asFloat(self):
+    def as_float(self) -> float | None:
         # return the float, with no suffix
-        if self.suffix == "½":
-            if self.num is not None:
-                return self.num + .5
-            else:
-                return .5
+        if len(self.suffix) == 1 and self.suffix.isnumeric():
+            return (self.num or 0) + unicodedata.numeric(self.suffix)
         return self.num
-
-    def asInt(self):
-        # return the int version of the float
-        if self.num is None:
-            return None
-        return int(self.num)
